#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include <stdio.h>
#include <sndfile.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#include "convolve.h"
#include "window.h"

#define BUFFER_LENGTH 1024

void
on_button1_pressed                     (GtkButton       *button,
                                        gpointer         user_data)
{
	gtk_widget_show(fileselection1);
}


gboolean
on_ok_button1_button_press_event       (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{
  char *fn = gtk_file_selection_get_filename(fileselection1);
  SNDFILE *infile;
  SF_INFO sfinfo;
  int i, readcount, pos;
  float size;
  double data[BUFFER_LENGTH];
  float *impulse_time;

  gtk_widget_hide(fileselection1);
  if (!(infile = sf_open_read(fn, &sfinfo))) {
    fprintf(stderr, "Can't open '%s' for reading.\n", fn);
    sf_perror(NULL);
    return FALSE;
  }
	
  printf("Channels: %d\n", sfinfo.channels);
  printf("Sample rate: %d\n", sfinfo.samplerate);
  printf("Length: %d\n", sfinfo.samples);

  impulse_time = malloc((MAX_FFT_LENGTH - SEG_LENGTH) * sizeof(float));

  pos = 0;
  while ((readcount = sf_read_double(infile, data, BUFFER_LENGTH, 1))) {
//printf("%d\n", pos);
    for (i=0; i<readcount; i++) {
      if (pos > MAX_FFT_LENGTH - SEG_LENGTH) {
        fprintf(stderr, "Warning: impulse too long.\n");
        break;
      }
      if ((i % sfinfo.channels) == 0) {
         impulse_time[pos++ % 80000] = (float)data[i];
      }
    }
  }
  sf_close(infile);

  impulse2freq(impulse_time, pos, impulse_freq);
  free(impulse_time);

  return FALSE;
}


void
on_cancel_button1_clicked              (GtkButton       *button,
                                        gpointer         user_data)
{
  gtk_widget_hide(fileselection1);
}

